@@ -1,6 +1,15 @@
 package JSON::JOM::Plugins::ListUtils;
 
-our $VERSION   = '0.005';
+use 5.010;
+use strict;
+use utf8;
+use Object::AUTHORITY;
+
+BEGIN
+{
+	$JSON::JOM::Plugins::ListUtils::AUTHORITY = 'cpan:TOBYINK';
+	$JSON::JOM::Plugins::ListUtils::VERSION   = '0.500';
+}
 
 sub extensions
 {
@@ -56,10 +65,16 @@ Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
 =head1 COPYRIGHT
 
-Copyright 2010 Toby Inkster
+Copyright 2010-2011 Toby Inkster
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
+=head1 DISCLAIMER OF WARRANTIES
+
+THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
+WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
+MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+
 =cut
 
